@@ -5,6 +5,7 @@ package IO::ReadPreProcess;
 # It provides IO::Handle-ish functions to slot in easily to most scripts.
 
 # Author Alain D D Williams <addw@phcomp.co.uk> March 2015, 2016, 2017 Copyright (C) the author.
+# SCCS: @(#)ReadPreProcess.pm	1.10 05/25/17 16:03:07
 
 use 5.006;
 use strict;
@@ -17,7 +18,7 @@ our $errstr; # Error string
 
 use Math::Expression;
 
-our $VERSION = 0.80;
+our $VERSION = 0.81;
 
 # Control directive recognised by getline():
 my %ctlDirectives = map { $_ => 1 } qw/ break case close continue do done echo else elseif elsif endswitch error eval exit
@@ -1426,6 +1427,10 @@ files included: .if/.else/.elseif/.fi, do: .include .let .print, loops: .while
 
 Provides IO::Handle-ish functions and input diamond - thus easy to slot in to existing scripts.
 
+The preprocessing layer has variables that can be set and read by your perl code.
+In the input files they are set via C<.let> directives, and can be made part of your
+script's input with C<.echo> and C<\v{xxx}>.
+
 C<IO::ReadPreProcess> returns lines from the input stream.
 This may have directives that include:
 
@@ -1546,9 +1551,42 @@ may be directly assigned to at any time.
 
 Eg:
 
- $fh->Raw = 1;
+    $fh->Raw = 1;
 
-The last line read was from file C<File> at line number C<LineNumber>. This is conveniently summarised in C<Place>, useful for error messages.
+Also the following:
+
+=over 4
+
+=item C<Math>
+
+Note that there are many useful values that you can get here,
+some set by C<IO::ReadPreProcess> (see below), others by C<.let> directives.
+You can thus communicate with the preprocessing layer.
+
+Eg:
+
+You can set C<Math> variables like this:
+
+    $fh->{Math}->VarSetScalar('FirstName', 'Henry');
+
+You can get C<Math> variable values like this:
+
+    $name = $fh->{Math}->ParseToScalar('FirstName');
+
+    $fileName = $fh->{Math}->ParseToScalar('_FileName');
+
+=item C<Place>
+
+A string that can be used in messages to the user about the current input place.
+The value will be like:
+
+    line 201 of slides/regular-expressions.mod
+
+Eg:
+
+    warn "Something wrong at $fh->{Place}\n";
+
+=back
 
 =head1 METHODS
 
@@ -1697,6 +1735,8 @@ C<.elsif> is a synonym for C<.elseif>.
 
 C<.unless> is the same as C<.if> except that the truthness of the result is considered inverted.
 
+Text following C<.fi> or C<.else> will be ignored - you may use as comment.
+
 The condition may be a defined subroutine which will be run and the value set by C<.return> used
 as the boolean. The arguments are processed as if by C<.print>.
 
@@ -2154,6 +2194,7 @@ what it reads.
 
 Most of the interest lies in the input:
 
+    .let sum := 0
     A line of input
 
     .# Check to see if this is advanced
@@ -2166,8 +2207,9 @@ Most of the interest lies in the input:
 
     .# Bring in an extra file:
     .include extra_files/very_complex
+    .let sum = sum + 2
 
-    .fi
+    .fi advanced > 1
     .else
 
     Simple stuff
@@ -2183,6 +2225,11 @@ Most of the interest lies in the input:
 
 For more examples see the test suite.
 
+At the end of the run you might want to do this:
+
+    # Some stats, for fun:
+    say STDERR $fh->{Math}->ParseToScalar('printf("Preprocessing: lines generated %d, skipped %d. Directives %d, frames opened %d, files opened %d", _CountGen, _CountSkip, _CountDirect, _CountFrames, _CountOpen)');
+
 =head1 SECURITY
 
 Do be aware that a C<.include> will open any file for which the process has permissions.
